@@ -18,18 +18,16 @@ or
 [VaspWorkflow](https://jacksund.github.io/simmate/full_guides/workflows/third_party_software/vasp/overview/)
 """
 
-from simmate.calculators.vasp.error_handlers import (  # There are many more available too!
+from simmate.apps.vasp.error_handlers import (  # There are many more available too!
     Frozen,
     NonConverging,
     Unconverged,
     Walltime,
 )
-from simmate.calculators.vasp.inputs import Incar
-from simmate.calculators.vasp.inputs.potcar_mappings import (
-    PBE_ELEMENT_MAPPINGS_LOW_QUALITY,
-)
-from simmate.calculators.vasp.workflows.base import VaspWorkflow
-from simmate.workflow_engine import Workflow
+from simmate.apps.vasp.inputs import Incar
+from simmate.apps.vasp.inputs.potcar_mappings import PBE_ELEMENT_MAPPINGS_LOW_QUALITY
+from simmate.apps.vasp.workflows.base import VaspWorkflow
+from simmate.engine import Workflow
 
 # Import our tables from the other files.
 from .models import MyCustomTable1
@@ -49,7 +47,6 @@ __all__ = [
 
 
 class Example__Python__MyExample1(Workflow):
-
     database_table = MyCustomTable1
 
     @staticmethod
@@ -73,7 +70,6 @@ class Example__Python__MyExample1(Workflow):
 
 
 class Relaxation__Vasp__MyExample2(VaspWorkflow):
-
     # This uses the PBE functional with POTCARs that have lower electron counts
     # and convergence criteria when available.
     functional = "PBE"
@@ -124,6 +120,7 @@ class Relaxation__Vasp__MyExample2(VaspWorkflow):
 # If you need to add advanced logic for one of your INCAR tags, you can register
 # a keyword_modifier to the INCAR class like so:
 
+
 # first define the logic of your modifier as a function
 def keyword_modifier_multiply_nsites(structure, example_mod_input):
     # add your advanced logic to determine the keyword value.
