@@ -530,7 +530,7 @@ class DatabaseTable(models.Model):
                 workflow = get_workflow(self.workflow_name)
                 all_data["_WEBSITE_URL_"] = (
                     "http://127.0.0.1:8000/workflows/"  # I assume local host for now
-                    f"{workflow.name_type}/{workflow.name_calculator}/"
+                    f"{workflow.name_type}/{workflow.name_app}/"
                     f"{workflow.name_preset}/{self.id}"
                 )
         except:
@@ -549,7 +549,6 @@ class DatabaseTable(models.Model):
 
     @classmethod
     def from_dict(cls, source_dict: dict):
-
         # start by loading the datbase table, which is given as a module path
         table_name = source_dict["database_table"]
         datatable = cls.get_table(table_name)
@@ -618,7 +617,6 @@ class DatabaseTable(models.Model):
         return all_data_ordered
 
     def get_table(table_name: str):
-
         # This method can be return ANY table, so we need to import all of them
         # here. This is a local import to prevent circular import issues.
         from simmate.website.third_parties import models as third_party_datatables
@@ -652,7 +650,7 @@ class DatabaseTable(models.Model):
         if vasprun_filename.exists():
             return cls.from_vasp_directory(directory, as_dict=as_dict)
 
-        # TODO: add new elif statements when I begin adding new calculators.
+        # TODO: add new elif statements when I begin adding new apps.
 
         # If we don't detect any directory, we return an empty dictionary.
         # We don't print a warning or error for now because users may want
@@ -661,8 +659,7 @@ class DatabaseTable(models.Model):
 
     @classmethod
     def from_vasp_directory(cls, directory: Path, as_dict: bool = False):
-
-        from simmate.calculators.vasp.outputs import Vasprun
+        from simmate.apps.vasp.outputs import Vasprun
 
         vasprun = Vasprun.from_directory(directory)
         return cls.from_vasp_run(vasprun, as_dict=as_dict)
@@ -767,9 +764,9 @@ class DatabaseTable(models.Model):
         all_data.pop("migration_images", None)
         all_data.pop("band_structure", None)
         all_data.pop("density_of_states", None)
+        all_data.pop("molecule", None)
 
         for parent in parents:
-
             # Skip the parent class if it doesn't directly inherit from the
             # DatabaseTable class. We do this because we want the fundamental
             # mixins that come with Simmate (such as Structure, Forces, Thermodynamics).
@@ -821,7 +818,6 @@ class DatabaseTable(models.Model):
     @classmethod
     @property
     def archive_fieldset(cls) -> list[str]:
-
         all_fields = ["id", "updated_at", "created_at", "source"]
 
         # If calling this method on the base class, just return the sole mix-in.
@@ -990,7 +986,6 @@ class DatabaseTable(models.Model):
                 load_single_entry(entry)
         # otherwise we use dask to submit these in batches!
         else:
-
             from simmate.configuration.dask import batch_submit
 
             batch_submit(
