@@ -213,6 +213,9 @@ class MigrationImages(list):
         structure_start: Structure,
         structure_end: Structure,
         nimages: int = 5,
+        species: list[str] = None,
+        sort_tol: float = 0,
+        idpp_relax: bool = True,
         **kwargs,
     ):
         """
@@ -237,13 +240,26 @@ class MigrationImages(list):
             Any arguments that are normally accepted by IDPPSolver
         """
 
-        # Run IDPP relaxation on the images before returning them
-        idpp_solver = IDPPSolver.from_endpoints(
-            [structure_start, structure_end],
-            nimages=nimages,
-            **kwargs,
-        )
-        images = idpp_solver.run()
+        if idpp_relax:
+            # Run IDPP relaxation on the images before returning them
+            idpp_solver = IDPPSolver.from_endpoints(
+                [structure_start, structure_end],
+                nimages=nimages,
+                interpolate_lattices=True,
+                sort_tol=sort_tol,
+            )
+            images = idpp_solver.run(
+                species=species,
+                **kwargs,
+            )
+        else:
+            # Run a basic linear interpolation
+            images = structure_start.interpolate(
+                structure_end,
+                nimages=nimages + 1,
+                autosort_tol=sort_tol,
+                interpolate_lattices=True,
+            )
 
         return cls(images)
 
@@ -331,7 +347,6 @@ class MigrationImages(list):
         # these as a list of paths.
         migration_paths = []
         for pathway in pathways:
-
             migration_path = cls.from_migration_hop(
                 migration_hop=pathway,
                 **kwargs,
