@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
 
+import importlib
+
 from django.contrib.auth.decorators import login_required
 from django.db.models import F
 from django.shortcuts import render
 
+from simmate.configuration.django.settings import SIMMATE_APPS
 from simmate.database.third_parties import (
     AflowStructure,
     CodStructure,
@@ -31,7 +34,6 @@ def loginstatus(request):
 
 
 def home(request):
-
     # The home page is also an html "form" because users submit queries from
     # here. So we need to handle form submissions properly.
 
@@ -42,7 +44,6 @@ def home(request):
         form = ChemicalSystemForm(request.POST)
         # see if all of the data is valid
         if form.is_valid():
-
             # grab the cleaned data from the form
             cleaned_data = form.cleaned_data
 
@@ -110,6 +111,31 @@ def home(request):
     return render(request, template, context)
 
 
+def apps(request):
+    ################
+    # This section of code is copied from...
+    #   simmate.web.core.urls
+    # Consider making another util. I might want a SimmateConfig class that
+    # subclasses Django app's Config class. Add things like "learn-more" links
+    # and short descriptions
+    extra_apps = []
+    for app_name in SIMMATE_APPS:
+        config_modulename = ".".join(app_name.split(".")[:-1])
+        config_name = app_name.split(".")[-1]
+        config_module = importlib.import_module(config_modulename)
+        config = getattr(config_module, config_name)
+        app_path = config.name
+        simple_name = app_path.split(".")[-1]
+        urls_found = importlib.util.find_spec(f"{app_path}.urls") is not None
+        if urls_found:
+            extra_apps.append(simple_name)
+            # TODO: maybe grab a short description too?
+    ################
+    context = {"extra_apps": extra_apps}
+    template = "core_components/apps.html"
+    return render(request, template, context)
+
+
 def extras(request):
     context = {}
     template = "core_components/extras.html"
